@@ -21,6 +21,14 @@ from .asset_service import (
     AnalyzeIamPolicyResponse,
     AnalyzeMoveRequest,
     AnalyzeMoveResponse,
+    AnalyzeOrgPoliciesRequest,
+    AnalyzeOrgPoliciesResponse,
+    AnalyzeOrgPolicyGovernedAssetsRequest,
+    AnalyzeOrgPolicyGovernedAssetsResponse,
+    AnalyzeOrgPolicyGovernedContainersRequest,
+    AnalyzeOrgPolicyGovernedContainersResponse,
+    AnalyzerOrgPolicy,
+    AnalyzerOrgPolicyConstraint,
     BatchGetAssetsHistoryRequest,
     BatchGetAssetsHistoryResponse,
     BatchGetEffectiveIamPoliciesRequest,
@@ -95,6 +103,14 @@ __all__ = (
     "AnalyzeIamPolicyResponse",
     "AnalyzeMoveRequest",
     "AnalyzeMoveResponse",
+    "AnalyzeOrgPoliciesRequest",
+    "AnalyzeOrgPoliciesResponse",
+    "AnalyzeOrgPolicyGovernedAssetsRequest",
+    "AnalyzeOrgPolicyGovernedAssetsResponse",
+    "AnalyzeOrgPolicyGovernedContainersRequest",
+    "AnalyzeOrgPolicyGovernedContainersResponse",
+    "AnalyzerOrgPolicy",
+    "AnalyzerOrgPolicyConstraint",
     "BatchGetAssetsHistoryRequest",
     "BatchGetAssetsHistoryResponse",
     "BatchGetEffectiveIamPoliciesRequest",
