@@ -775,7 +775,7 @@ class AssetServiceAsyncClient:
             metadata=metadata,
         )
 
-    async def __aenter__(self):
+    async def __aenter__(self) -> "AssetServiceAsyncClient":
         return self
 
     async def __aexit__(self, exc_type, exc, tb):
