@@ -50,6 +50,7 @@ from google.cloud.asset_v1p2beta1.types import asset_service
 from .transports.base import AssetServiceTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc import AssetServiceGrpcTransport
 from .transports.grpc_asyncio import AssetServiceGrpcAsyncIOTransport
+from .transports.rest import AssetServiceRestTransport
 
 
 class AssetServiceClientMeta(type):
@@ -63,6 +64,7 @@ class AssetServiceClientMeta(type):
     _transport_registry = OrderedDict()  # type: Dict[str, Type[AssetServiceTransport]]
     _transport_registry["grpc"] = AssetServiceGrpcTransport
     _transport_registry["grpc_asyncio"] = AssetServiceGrpcAsyncIOTransport
+    _transport_registry["rest"] = AssetServiceRestTransport
 
     def get_transport_class(
         cls,
