@@ -346,7 +346,7 @@ class AssetServiceAsyncClient:
         # Done; return the response.
         return response
 
-    async def __aenter__(self):
+    async def __aenter__(self) -> "AssetServiceAsyncClient":
         return self
 
     async def __aexit__(self, exc_type, exc, tb):
